# v0.0.7 - Jan 29, 2024

- Bug fix: Updated DoubletFinder with modified function names.
- Added "-D|--define" to support defining an individual sample without a SAMPLEFILE.

# v0.0.6 - Mar 8, 2023

- Added support for "skip=True" in DoubletFinder, useful for multiplex libraries.

# v0.0.5 - Feb 16, 2023

- Separated sample file (e.g., samples.txt) from config.yaml.

# v0.0.4 - Dec 16, 2022

- Updated installation instructions using conda.

# v0.0.3 - Oct 31, 2022

## Initial Implementation

- Implemented conditional execution for Dropkick and scPred.
- Implemented qc_report.html for a QC summary.

